@@ -58,7 +58,7 @@ public:
 
     virtual BOOL HagakiFeedDuplexerPresent(BOOL bQueryPrinter);
 #endif
-
+    virtual BOOL GetMargins (PAPER_SIZE ps, float *fMargins);
 
 private:
 	virtual void AdjustModeSettings (BOOL bDoFullBleed, MEDIATYPE ReqMedia,
@@ -66,6 +66,24 @@ private:
 
 }; //DJGenericVIP
 
+class VIPFastDraftMode : public PrintMode
+{
+public:
+    VIPFastDraftMode ();
+}; // VIPFastDraftMode
+
+class VIPGrayFastDraftMode : public GrayMode
+{
+public:
+    VIPGrayFastDraftMode ();
+}; // VIPGrayFastDraftMode
+
+class VIPAutoPQMode : public PrintMode
+{
+public:
+    VIPAutoPQMode ();
+}; // VIPAutoPQMode
+
 #if defined(APDK_DJGENERICVIP) && defined (APDK_DJ9xxVIP)
 //! DJGenericVIPProxy
 /*!
@@ -75,47 +93,59 @@ class DJGenericVIPProxy : public PrinterProxy
 public:
     DJGenericVIPProxy() : PrinterProxy(
         "GenericVIP",                       // family name
-        "photosmart 7150\0"                 // Twister
-        "photosmart 7350\0"                 // Dorothy
-		"photosmart 7345\0"                 // Dorothy
-        "photosmart 7550\0"                 // Tinman
-        "deskjet 5550\0"                    // Malibu
-        "deskjet 5551\0"                    // Malibu Japan
-        "dj450\0"                           // Crystal
-		"deskjet 450\0"                     // Crystal Plus
-        "photosmart 7960\0"                 // Gran Prix
-        "photosmart 7760\0"                 // Bonneville
-		"photosmart 7660\0"                 // Catalina
-        "photosmart 7260\0"                 // Crayola
-		"photosmart 7268\0"                 // Crayola
-        "deskjet 5600\0"                    // Malibu +
-        "deskjet 5100\0"                    // Malibu Mid
-		"deskjet 5800\0"                    // Gepetto
-		"deskjet 9600\0"                    // Euclid
-		"Deskjet 6500\0"                    // Dolphin
-		"Deskjet 5700\0"                    // Pelican Plus
-		"Deskjet 6800\0"                    // Marlin
-		"Photosmart 7400\0"					// Yogi
-		"Photosmart 8100\0"                 // Shaggy
-		"Photosmart 8400\0"                 // Squiddly
+        "dj450\0"
+		"deskjet 450\0"
+        "deskjet 5550\0"
+        "deskjet 5551\0"
+        "deskjet 5600\0"
+        "deskjet 5100\0"
+		"Deskjet 5700\0"
+		"deskjet 5800\0"
+		"Deskjet 6500\0"
+		"Deskjet 6600\0"
+		"Deskjet 6800\0"
+		"deskjet 9600\0"
+		"Deskjet 9800\0"
+		"hp business inkjet 1100\0"
+   		"HP Business Inkjet 1200\0"
+        "photosmart 7150\0"
+        "photosmart 7350\0"
+		"photosmart 7345\0"
+        "photosmart 7550\0"
+        "photosmart 7960\0"
+        "photosmart 7760\0"
+		"photosmart 7660\0"
+        "photosmart 7260\0"
+		"photosmart 7268\0"
+		"Photosmart 7400\0"
+		"Photosmart 8100\0"
+		"Photosmart 8400\0"
+		"Photosmart 8700\0"
+		"Photosmart 8200\0"
+        "Business Inkjet 1000\0"
+		"Photosmart 320\0"
+		"Photosmart 370\0"
+		"Photosmart 380\0"
+		"Photosmart 330\0"
 #ifdef APDK_MLC_PRINTER
-        "PSC 2100\0"                        // Bonzai               
+		"PSC 1500\0"
+		"PSC 1600\0"
+        "PSC 2100\0"              
         "PSC 2150\0"
         "PSC 2200\0"
-        "psc 2300\0"                        // Bonzai + Lo
-        "psc 2400\0"                        // Bonzai + Mid
-        "psc 2500\0"                        // Bonzai + Hi
-		"PSC 2170\0"                        // Bonzai 3P
-		"OfficeJet 6100\0"                  // Solar
-		"OfficeJet 6150\0"                  // Solar Japan
-		"Officejet 7400\0"                  // Atlas Super
-		"Officejet 7300\0"                  // Atlas Mid
-		"Officejet 7200\0"                  // Atlas Base
-		"Officejet 6200\0"                  // Balboa Base
-		"psc 1600\0"                        // Shazam Base
-		"psc 2350\0"                        // Shazam High
-		"Photosmart 2600\0"                 // Ares Mid
-		"Photosmart 2700\0"                 // Ares Super
+        "psc 2300\0"
+		"PSC 2350\0"
+        "psc 2400\0"
+        "psc 2500\0"
+		"PSC 2170\0"
+		"OfficeJet 6100\0"
+		"OfficeJet 6150\0"
+		"Officejet 7400\0"
+		"Officejet 7300\0"
+		"Officejet 7200\0"
+		"Officejet 6200\0"
+		"Photosmart 2600\0"
+		"Photosmart 2700\0"
 #endif
     ) {m_iPrinterType = eDJGenericVIP;}
     inline Printer* CreatePrinter(SystemServices* pSS) const { return new DJGenericVIP(pSS); }
