@@ -406,7 +406,7 @@ int hpijs_get_client_raster(IjsServerCtx *ctx, char *buf, int size, char white)
 int main(int argc, char *argv[])
 {
    UXServices *pSS = NULL;
-   IjsServerCtx *ctx;
+   IjsServerCtx *ctx = NULL;
    char *raster = NULL, *k_raster = NULL;
    int status = EXIT_FAILURE;
    int ret, n, i, kn=0, width, k_width;
@@ -442,11 +442,22 @@ int main(int argc, char *argv[])
 #endif
 
    pSS->pPC = new PrintContext(pSS, 0, 0);
-   if (pSS->pPC->constructor_error != NO_ERROR)
+
+   /* Ignore JOB_CANCELED. This a bi-di hack that allows the job to continue even if bi-di communication failed. */
+   if (pSS->pPC->constructor_error > 0 && pSS->DisplayStatus != DISPLAY_PRINTING_CANCELED)
    {
       bug("unable to open PrintContext object err=%d\n", pSS->pPC->constructor_error);
       goto BUGOUT;
    }
+   if (pSS->pPC->constructor_error < 0)
+      bug("WARNING: %s\n", pSS->GetDriverMessage(pSS->pPC->constructor_error));
+
+#if 0
+   bug("device model=%s\n", pSS->pPC->PrinterModel());
+   bug("device class=%s\n",  pSS->pPC->PrintertypeToString(pSS->pPC->SelectedDevice()));
+   bug("default pen=%d\n",  pSS->pPC->GetDefaultPenSet());
+   bug("installed pen=%d\n",  pSS->pPC->GetInstalledPens());
+#endif
 
    ijs_server_install_status_cb (ctx, hpijs_status_cb, pSS);
    ijs_server_install_list_cb (ctx, hpijs_list_cb, pSS);
@@ -486,6 +497,10 @@ int main(int argc, char *argv[])
             bug("unable to SetPixelsPerRow width=%d, err=%d\n", pSS->ph.width, ret);
          }
 
+         /* Turn off any bi-di support. Allow bi-di for printer capabilities only. */
+//         pSS->IOMode.bDevID = pSS->IOMode.bStatus = FALSE;
+         pSS->ResetIOMode (FALSE, FALSE);
+
          if (pSS->pJob != NULL)
             delete pSS->pJob;
          pSS->pJob = new Job(pSS->pPC);
@@ -581,13 +596,13 @@ int main(int argc, char *argv[])
       }
    }
 
- BUGOUT:
-   if (pSS->pJob != NULL)
-      delete pSS->pJob;
-   if (pSS->pPC != NULL)
-      delete pSS->pPC;
+BUGOUT:
    if (pSS != NULL)
    {
+      if (pSS->pJob != NULL)
+         delete pSS->pJob;
+      if (pSS->pPC != NULL)
+         delete pSS->pPC;
 #ifdef CAPTURE
       pSS->EndScript();
 #endif
@@ -597,7 +612,8 @@ int main(int argc, char *argv[])
       free(raster);
    if (k_raster != NULL)
       free(k_raster);
-   ijs_server_done(ctx);
+   if (ctx != NULL)
+      ijs_server_done(ctx);
 
    exit(status);
 }
