@@ -73,6 +73,8 @@ enum STYLE_TYPE { UPRIGHT, ITALIC };
 
 enum WEIGHT_TYPE { NORMAL, BOLD };
 
+enum DATA_FORMAT { RASTER_LINE, RASTER_STRIP };
+
 
 ///////////////////////////////////////////////////////////////////
 
@@ -112,10 +114,10 @@ const char SeedSame[] = {ESC, '*', 'b', '0', 'S'};
 const char BlackExtractOff[] = {ESC, '*', 'o', '5', 'W', 0x04, 0xC, 0, 0, 0 };
 const char LF = '\012';
 const char Quote = '\042';
-const BYTE Venice_Power_On[] = {ESC, '%','P','u','i','f','p','.',
+const BYTE DJ895_Power_On[] = {ESC, '%','P','u','i','f','p','.',
         'p','o','w','e','r',' ','1',';',
         'u','d','w','.','q','u','i','t',';',ESC,'%','-','1','2','3','4','5','X' };
-/*const BYTE Venice_Pre_Pick[] = {ESC, '&', 'l', -2, 'H'};
+/*const BYTE DJ895_Pre_Pick[] = {ESC, '&', 'l', -2, 'H'};
 {ESC, '%','P','m','e','c','h','.',
         'l','o','a','d','_','p','a','p','e','r',';',
         'u','d','w','.','q','u','i','t',';' };//,ESC,'%','-','1','2','3','4','5','X' };
@@ -196,6 +198,43 @@ struct RASTERDATA
     BYTE*	rasterdata[MAX_COLORTYPE];
 };
 
+// Bitmap structure definition
+struct HPRGBQUAD {
+  BYTE    rgbBlue; 
+  BYTE    rgbGreen; 
+  BYTE    rgbRed; 
+  BYTE    rgbReserved; 
+};
+
+struct HPBITMAPINFOHEADER{
+  DWORD  biSize; 
+  long   biWidth; 
+  long   biHeight; 
+  WORD   biPlanes; 
+  WORD   biBitCount; 
+  DWORD  biCompression; 
+  DWORD  biSizeImage; 
+  long   biXPelsPerMeter; 
+  long   biYPelsPerMeter; 
+  DWORD  biClrUsed; 
+  DWORD  biClrImportant; 
+}; 
+
+struct HPBITMAPINFO { 
+  HPBITMAPINFOHEADER bmiHeader; 
+  HPRGBQUAD          bmiColors[1]; 
+}; 
+
+
+struct HPLJBITMAP {
+
+    HPBITMAPINFO  bitmapInfo;
+    unsigned long cjBits;
+    BYTE          *pvBits;	
+	BYTE          *pvAlignedBits;
+};
+
+
 //////////////////////////////////////////
 class Pipeline;
 //Scaler, Halftoner, ColorMatcher, ErnieFilter, PixelReplicator,
@@ -294,7 +333,7 @@ public:
     // constructor protected -- use Create_Scaler()
     virtual ~Scaler();
     //virtual BOOL Process(BYTE* InputRaster=NULL, unsigned int size=0)=0;
-    virtual BOOL Process(RASTERDATA* InputRaster=NULL)=0;
+    BOOL Process(RASTERDATA* InputRaster=NULL)=0;
     virtual void Flush() { Process(); }
 
     DRIVER_ERROR constructor_error;
@@ -333,6 +372,14 @@ class LJMonoProxy;
 class LJColorProxy;
 #endif
 
+#ifdef APDK_LJJETREADY
+class LJJetReadyProxy;
+#endif
+
+#ifdef APDK_LJFASTRASTER
+class LJFastRasterProxy;
+#endif
+
 #if defined(APDK_PSP100) && defined (APDK_DJ9xxVIP)
 class PSP100Proxy;
 #endif
@@ -463,6 +510,14 @@ public:
     static LJColorProxy s_LJColorProxy;
 #endif
 
+#ifdef APDK_LJJETREADY
+	static LJJetReadyProxy s_LJJetReadyProxy;
+#endif
+
+#ifdef APDK_LJFASTRASTER
+    static LJFastRasterProxy s_LJFastRasterProxy;
+#endif
+
 #if defined(APDK_PSP100) && defined (APDK_DJ9xxVIP)
     static PSP100Proxy s_PSP100Proxy;
 #endif
@@ -601,11 +656,12 @@ public:
 class Mode9 : public Compressor
 {
 public:
-    Mode9(SystemServices* pSys,unsigned int RasterSize);
+    Mode9(SystemServices* pSys,unsigned int RasterSize, BOOL bVIPPrinter = FALSE);
     virtual ~Mode9();
     BOOL Process(RASTERDATA* input);
     void Flush();
 	BOOL ResetSeedRow;
+    BOOL m_bVIPPrinter;
 }; //Mode9
 
 //ClassName
@@ -721,8 +777,11 @@ Composes a header stream, embodying specific requirements of the Printer.
 class Header
 {
 friend class Job;
+friend class ModeJPEG;
+
 public:
     Header(Printer* p,PrintContext* pc);
+    virtual ~Header ();
 
     virtual DRIVER_ERROR Send()=0;
 
@@ -731,6 +790,9 @@ public:
     virtual DRIVER_ERROR SendCAPy(unsigned int iAbsY);  // made virtual for crossbow
     virtual DRIVER_ERROR FormFeed();                    // made virtual for crossbow
 
+	BOOL	IsLastBand() { return bLastBand; }
+	void	SetLastBand(BOOL lastband) { bLastBand = lastband; }
+
     unsigned int CAPy;  // may be moved during header; retrieved by Job
 
 protected:
@@ -770,7 +832,7 @@ protected:
     char mediasource[6]; BYTE msrccount;    // mediasource string, and its size
     char quality[6]; BYTE qualcount;        // quality string, and its size
     BYTE QualityCode();         // returns just the variable byte of quality
-
+	BOOL bLastBand;
 }; //Header
 
 
@@ -891,16 +953,16 @@ protected:
 //ClassName
 /*
 ******************************************************************************/
-class HeaderAladdin : public Header
+class HeaderDJ990 : public Header
 {
 public:
-    HeaderAladdin(Printer* p,PrintContext* pc);
+    HeaderDJ990(Printer* p,PrintContext* pc);
     DRIVER_ERROR ConfigureRasterData();
     DRIVER_ERROR ConfigureImageData();
     DRIVER_ERROR Send();
     DRIVER_ERROR StartSend();
     void SetMediaSource(MediaSource msource);
-}; //HeaderAladdin
+}; //HeaderDJ990
 
 
 //ClassName
@@ -978,7 +1040,7 @@ protected:
     DRIVER_ERROR Graphics ();
     DRIVER_ERROR StartSend ();
     DRIVER_ERROR SendCAPy (unsigned int iAbsY);
-}; //HeaderLJMono
+}; //HeaderLJColor
 
 //ClassName
 /*
@@ -995,6 +1057,46 @@ protected:
     DRIVER_ERROR StartSend ();
 };
 
+//ClassName
+/*
+******************************************************************************/
+class HeaderLJJetReady : public Header
+{
+	friend class LJJetReady;
+public:
+    HeaderLJJetReady (Printer* p,PrintContext* pc);
+    virtual DRIVER_ERROR Send();
+	virtual DRIVER_ERROR FormFeed ();
+	virtual DRIVER_ERROR StartPage();
+	virtual DRIVER_ERROR EndPage();
+protected:
+    DRIVER_ERROR EndJob ();
+    DRIVER_ERROR StartSend ();
+    DRIVER_ERROR SendCAPy (unsigned int iAbsY);
+	DRIVER_ERROR MapPCLMediaTypeToString (MEDIATYPE eM);
+	int			 JRPaperToMediaSize(PAPER_SIZE ps);
+}; //HeaderLJJetReady
+
+//ClassName
+/*
+******************************************************************************/
+class HeaderLJFastRaster : public Header
+{
+	friend class LJFastRaster;
+public:
+    HeaderLJFastRaster (Printer* p,PrintContext* pc);
+    virtual DRIVER_ERROR Send();
+	virtual DRIVER_ERROR FormFeed ();
+	virtual DRIVER_ERROR StartPage();
+	virtual DRIVER_ERROR EndPage();
+protected:
+    DRIVER_ERROR EndJob ();
+    DRIVER_ERROR StartSend ();
+    DRIVER_ERROR SendCAPy (unsigned int iAbsY);
+	DRIVER_ERROR MapPCLMediaTypeToString (MEDIATYPE eM);
+	int			 FrPaperToMediaSize(PAPER_SIZE ps);
+}; //HeaderLJFastRaster
+
 //RasterSender
 //! Send rasters to the device
 /*!
