@@ -174,10 +174,10 @@ int UXServices::ProcessRaster(char *raster, char *k_raster)
 UXServices::UXServices():SystemServices()
 {
    char *hpDev;
+   MsgAttributes ma;
 
    constructor_error = NO_ERROR;
    hpFD = -1;
-   OldStatus = 0x55;
 
    // instead of InitDeviceComm(), just do...
    IOMode.bDevID = IOMode.bStatus = FALSE;   /* uni-di support is default */
@@ -187,13 +187,14 @@ UXServices::UXServices():SystemServices()
    {
       if (strncmp(hpDev, "hp:", 3) == 0)
       {
-         if ((hpFD = OpenHP(hpDev)) >= 0)
+         hplip_Init();
+         hplip_ModelQuery(hpDev, &ma);      /* check io-mode in models.xml for this device */  
+         if (ma.prt_mode != UNI_MODE)
          {
-            InitDeviceComm();            /* lets try bi-di support */
-         }
-         if(IOMode.bDevID == FALSE)
-         {
-            bug("unable to set bi-di for hp backend\n");
+            if ((hpFD = hplip_OpenHP(hpDev, &ma)) >= 0)
+               InitDeviceComm();            /* lets try bi-di support */
+            if(IOMode.bDevID == FALSE)
+               bug("unable to set bi-di for hp backend\n");
          }
       }
    }
@@ -214,14 +215,16 @@ UXServices::UXServices():SystemServices()
    Model = -1;
    strcpy(ph.cs, "sRGB");
    VertAlign = -1;
+   DisplayStatus = NODISPLAYSTATUS;
 }
 
 UXServices::~UXServices()
 {
-    if (RastersOnPage)
-        delete [] RastersOnPage;
+   if (RastersOnPage)
+      delete [] RastersOnPage;
    if (hpFD >= 0)
-      CloseHP(hpFD);   
+      hplip_CloseHP(hpFD);  
+   hplip_Exit(); 
 }
 
 DRIVER_ERROR UXServices::ToDevice(const BYTE * pBuffer, DWORD * Count)
@@ -229,7 +232,9 @@ DRIVER_ERROR UXServices::ToDevice(const BYTE * pBuffer, DWORD * Count)
    /* Write must be not-buffered, don't use streams */
    if (write(OutputPath, pBuffer, *Count) != (ssize_t)*Count) 
    {
-      bug("unable to write to output, fd=%d, count=%d: %m\n", OutputPath, *Count);
+      static int cnt=0;
+      if (cnt++ < 5)
+         bug("unable to write to output, fd=%d, count=%d: %m\n", OutputPath, *Count);
       return IO_ERROR;
    }
 
@@ -239,14 +244,14 @@ DRIVER_ERROR UXServices::ToDevice(const BYTE * pBuffer, DWORD * Count)
 
 BOOL UXServices::GetStatusInfo (BYTE * bStatReg)
 {
-   if (ReadHPStatus(hpFD, (char *)bStatReg, 1) == 1)
+   if (hplip_GetStatus(hpFD, (char *)bStatReg, 1) == 1)
       return TRUE;
    return FALSE;
 }
 
 DRIVER_ERROR UXServices::ReadDeviceID (BYTE * strID, int iSize)
 {
-   if (ReadHPDeviceID(hpFD, (char *)strID, iSize) < 3)
+   if (hplip_GetID(hpFD, (char *)strID, iSize) < 3)
       return IO_ERROR;
    return NO_ERROR;
 }
@@ -267,9 +272,36 @@ BOOL UXServices::GetVertAlignFromDevice()
    return TRUE;
 }
 
+void UXServices::DisplayPrinterStatus (DISPLAY_STATUS ePrinterStatus)
+{
+   DisplayStatus = ePrinterStatus;
+}
+
+DRIVER_ERROR UXServices::BusyWait (DWORD msec)
+{
+   switch (DisplayStatus)
+   {
+      case DISPLAY_ERROR_TRAP:
+      case DISPLAY_COMM_PROBLEM:
+      case DISPLAY_PRINTER_NOT_SUPPORTED:
+      case DISPLAY_OUT_OF_PAPER:
+      case DISPLAY_PHOTOTRAY_MISMATCH:
+      case DISPLAY_TOP_COVER_OPEN:
+      case DISPLAY_NO_COLOR_PEN:
+      case DISPLAY_NO_BLACK_PEN:
+      case DISPLAY_NO_PENS:
+         bug("WARNING: printer bi-di error=%d\n", DisplayStatus);
+         DisplayStatus = DISPLAY_PRINTING_CANCELED;
+         return JOB_CANCELED;   /* bail-out otherwise APDK will wait forever */
+      default:
+         break;
+   }
+   return NO_ERROR;
+}
+
 const char * UXServices::GetDriverMessage (DRIVER_ERROR err)
 {
-   char *p=NULL;
+   const char *p=NULL;
 
 	/* Map driver error to text message. TODO: text needs to be localized. */
    switch(err)
@@ -310,6 +342,18 @@ const char * UXServices::GetDriverMessage (DRIVER_ERROR err)
       case(WARN_LOW_INK_COLOR_BLACK_PHOTO):
          p = "color back pen has low ink";
          break;
+      case(WARN_LOW_INK_CYAN):
+         p = "cyan has low ink";
+         break;
+      case(WARN_LOW_INK_MAGENTA):
+         p = "magenta has low ink";
+         break;
+      case(WARN_LOW_INK_YELLOW):
+         p = "yellow has low ink";
+         break;
+      case(WARN_LOW_INK_MULTIPLE_PENS):
+         p = "more that one ink is low";
+         break;
       case(WARN_FULL_BLEED_UNSUPPORTED):
          p = "fullbleed is not supported";
          break;
@@ -374,3 +418,13 @@ int UXServices::MapPaperSize(float width, float height)
 
    return 0; 
 }
+
+void UXServices::ResetIOMode (BOOL bDevID, BOOL bStatus)
+{
+    if (pPC)
+    {
+        IOMode.bDevID  = bDevID;
+        IOMode.bStatus = bStatus;
+        pPC->ResetIOMode (bDevID, bStatus);
+    }
+}
