@@ -43,10 +43,7 @@ public:
   UXServices ();
   virtual ~ UXServices ();
 
-  DRIVER_ERROR BusyWait (DWORD msec)
-  {
-    return NO_ERROR;
-  }
+  DRIVER_ERROR BusyWait (DWORD msec);
 
   DRIVER_ERROR ToDevice (const BYTE* pBuffer, DWORD* wCount);
 
@@ -74,9 +71,7 @@ public:
     return rand ();
   }
 
-  void DisplayPrinterStatus (DISPLAY_STATUS ePrinterStatus)
-  {
-  }
+  void DisplayPrinterStatus (DISPLAY_STATUS ePrinterStatus);
 
   BYTE GetStatus ()
   {
@@ -116,6 +111,8 @@ public:
   void MapModel(const char *nam);
   const char * GetDriverMessage(DRIVER_ERROR err);
 
+  void  ResetIOMode (BOOL bDevID, BOOL bStatus);
+
   BOOL BackPage;
   int CurrentRaster;
   BYTE **RastersOnPage;
@@ -139,11 +136,21 @@ public:
   int FirstRaster;
   int KRGB;            /* 0=no, 1=yes */
   int hpFD;          /* CUPS hp backend file descriptor. */
-  BYTE OldStatus;
+  DISPLAY_STATUS DisplayStatus; /* current DisplayPrinterStatus */
   int VertAlign;    /* for Crossbow/Spear */
 
   PrintContext *pPC;
   Job *pJob;
+
+protected:
+  
+  // for internal use
+  virtual BYTE* AllocMem (int iMemSize, BOOL trackmemory)
+  { return AllocMem(iMemSize); }
+  
+  virtual void FreeMem (BYTE* pMem, BOOL trackmemory)
+  { FreeMem(pMem); }
+
 };
 
 #endif        /* hpijs_services_INCLUDED */
